@@ -7,7 +7,7 @@ class HentaiVnNet(Provider, Std):
         return self.chapter_id
 
     def get_content(self):
-        return self.http().get(self.get_url())
+        return self.http_get(self.get_url())
 
     def get_manga_name(self) -> str:
         return self._get_name(r'\.\w{2,7}/\d+(?:-\w+){2}-(.+)\.htm')
