@@ -13,7 +13,7 @@ class WieMangaCom(Provider, Std):
     def get_chapter_index(self) -> str:
         return self.re.search(r'/chapter/[^/]+/(\d+)/', self.chapter).group(1)
 
-    def get_main_content(self):
+    def get_content(self):
         return self._get_content('{}/manga/{}.html')
 
     def get_manga_name(self) -> str:
